Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(34)

Unified Diff: components/autofill/content/browser/request_autocomplete_manager.h

Issue 232263002: Console logging for rAc developer errors. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: platforms Created 6 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/autofill/content/browser/request_autocomplete_manager.h
diff --git a/components/autofill/content/browser/request_autocomplete_manager.h b/components/autofill/content/browser/request_autocomplete_manager.h
index 164f31c941e9460f47223fb86151a0d5cdc58189..aa5d25053194e472c89c7e78ad04a76378a2c4c5 100644
--- a/components/autofill/content/browser/request_autocomplete_manager.h
+++ b/components/autofill/content/browser/request_autocomplete_manager.h
@@ -33,9 +33,11 @@ class RequestAutocompleteManager {
private:
// Tells the renderer that the current interactive autocomplete dialog
// finished with the |result| saying if it was successful or not, and
// |form_structure| containing the filled form data.
void ReturnAutocompleteResult(
AutofillManagerDelegate::RequestAutocompleteResult result,
+ const base::string16& debug_message,
const FormStructure* form_structure);
// Shows the requestAutocomplete dialog for |source_url| with data from |form|
@@ -33,9 +33,11 @@ class RequestAutocompleteManager {
// Tells the renderer that the current interactive autocomplete dialog
// finished with the |result| saying if it was successful or not, and
- // |form_structure| containing the filled form data.
+ // |form_structure| containing the filled form data. |debug_message| will
+ // be printed to the developer console.
void ReturnAutocompleteResult(
AutofillManagerDelegate::RequestAutocompleteResult result,

Powered by Google App Engine
This is Rietveld 408576698